SubtitleDocument

Struct SubtitleDocument 

pub struct SubtitleDocument {
    pub cues: Vec<SubtitleCue>,
}
A parsed subtitle document containing a flat list of cues.

Fields

cues: Vec<SubtitleCue>

Ordered list of subtitle cues.

Implementations

Source

impl SubtitleDocument

pub fn replace_text(&mut self, id: usize, text: String) -> bool

Replace the text of the cue with the given id.

Returns true if the cue was found and replaced, false if no cue with that ID exists.